Create a "manifest" of downloaded and unzipped FLUXNET data files
Source:R/flux_discover_files.R
flux_discover_files.RdCreate a "manifest" of downloaded and unzipped FLUXNET data files
Arguments
- data_dir
The directory to look for FLUXNET CSV files in, typically the same as the
output_dirused forflux_extract().- ...
Arguments passed to
flux_listall().
Value
Prints a summary of discovered available data and returns
(invisibly) a dataframe with file paths and metadata extracted from file
names and merged in from flux_listall().
Examples
if (FALSE) { # \dontrun{
# Download data
flux_download(site_ids = c("AU-Boy", "BR-CST"))
# Extract annual and monthly data
flux_extract(resolutions = c("y", "m"))
# Create a manifest of extracted files
manifest <- flux_discover_files()
} # }