Extracts and tidies variable information from "BIFVARINFO" csv files.
Arguments
- manifest
A manifest data frame produced by
flux_discover_files().- resolution
The time resolution to read in. Must be one of
"y"(annual),"m"(monthly),"w"(weekly),"d"(daily), or"h"(hourly/half-hourly).- networks
A character vector indicating which networks to extract files from. Multiple values may be provided. Defaults to all networks.
- site_ids
A vector of site IDs to filter the manifest by. If
"all"(the default), the manifest isn't filtered by site ID.
Note
This only returns variable info (VARIABLE_GROUP == GRP_VAR_INFO) from
the "BIFVARINFO" files as much of the other metadata they contain can be
found in the results of flux_listall().
HEIGHT is returned as a character value because some heights are reported
as ranges and cannot be parsed as a single numeric value.
Examples
if (FALSE) { # \dontrun{
manifest <- flux_discover_files()
flux_varinfo(manifest)
} # }